import axios from 'axios'

const api = axios.create({
  baseURL: 'http://localhost:8080/api',  
  headers: {
    'Content-Type': 'application/json',
  }
})

api.interceptors.request.use(config => {
  const token = localStorage.getItem('token')
  if (token) {
    config.headers['Authorization'] = `Bearer ${token}`
  }
  return config
})

export const getChats = async () => {
  try {
    const response = await axios.get('/chats')
    return response.data
  } catch (error) {
    console.error('Error fetching chats:', error)
    throw error
  }
}

export const getChatById = async (chatId) => {
  try {
    const chats = JSON.parse(localStorage.getItem('chats') || '[]')
    const chat = chats.find(c => c.id === chatId)
    
    if (!chat) {

      const newChat = {
        id: chatId,
        movieName: localStorage.getItem(`movie_${chatId}`) || 'Чат фильма',
        messages: [],
        createdAt: new Date().toISOString()
      }
      
      chats.push(newChat)
      localStorage.setItem('chats', JSON.stringify(chats))
      return newChat
    }
    
    return chat
  } catch (error) {
    console.error('Ошибка при загрузке чата:', error)
    throw new Error('Не удалось загрузить чат')
  }
}

export const sendMessage = async (chatId, message) => {
  try {
    const chats = JSON.parse(localStorage.getItem('chats') || '[]')
    const chatIndex = chats.findIndex(c => c.id === chatId)
    
    if (chatIndex === -1) {
      throw new Error('Чат не найден')
    }

    const currentUser = JSON.parse(localStorage.getItem('user') || '{}')
    
    const newMessage = {
      id: Date.now(),
      text: message.text,
      timestamp: message.timestamp,
      authorId: currentUser.id,
      authorName: currentUser.name || 'Вы'
    }
    
    chats[chatIndex].messages.push(newMessage)
    localStorage.setItem('chats', JSON.stringify(chats))
    
    return newMessage
  } catch (error) {
    console.error('Ошибка при отправке сообщения:', error)
    throw new Error('Не удалось отправить сообщение')
  }
}

export const getMoviePoster = async (movieId) => {
  try {
    const response = await api.get(`/movies/${movieId}/poster`)
    return response
  } catch (error) {
    console.error(`Error fetching poster for movie ${movieId}:`, error)
    throw error
  }
}

export const getChatMessages = (chatId) => {
  return api.get(`/chats/${chatId}/messages`)
}

export default api