import axios from 'axios'
import { API_CONFIG } from '@/config/api'

const api = axios.create({
  baseURL: 'https://cinema.kolei.ru',
  timeout: 10000,
  headers: {
    'Content-Type': 'application/json'
  }
})

api.interceptors.request.use(config => {
  const token = localStorage.getItem('token')
  if (token) {
    config.headers['Authorization'] = `Bearer ${token}`
  }
  return config
})

api.interceptors.response.use(
  response => response,
  error => {
    if (error.response?.status === 401) {
      localStorage.removeItem('token')
      window.location.href = '/signin'
      return Promise.reject(new Error('Необходима авторизация'))
    }
    return Promise.reject(error)
  }
)

export const getUserProfile = async () => {
  try {
    const response = await api.get(API_CONFIG.endpoints.profile)
    return response.data
  } catch (error) {
    console.error('Get profile error:', error)
    throw error
  }
}

export const updateAvatar = async (formData) => {
  try {
    const response = await api.post(API_CONFIG.endpoints.avatar, formData, {
      headers: {
        'Content-Type': 'multipart/form-data'
      }
    })
    return response.data
  } catch (error) {
    console.error('Update avatar error:', error)
    throw error
  }
}