import api from '@/api'
import axios from 'axios'
import { API_CONFIG } from '@/config/api'
const jwt = require('jsonwebtoken');


const api = axios.create({
  baseURL: API_CONFIG.baseURL,
  timeout: 10000,
  headers: {
    'Content-Type': 'application/json'
  }
})

export const signin = async (credentials) => {
  try {
    const response = await api.post(API_CONFIG.endpoints.signin, credentials)
    if (response.data?.token) {
      localStorage.setItem('token', response.data.token)
      if (response.data.user) {
        localStorage.setItem('firstName', response.data.user.firstName || '')
        localStorage.setItem('lastName', response.data.user.lastName || '')
        localStorage.setItem('email', response.data.user.email || '')
      }
    }
    return response.data
  } catch (error) {
    console.error('Signin error:', error)
    throw new Error('Ошибка при входе. Проверьте данные и попробуйте снова.')
  }
}

module.exports = (req, res, next) => {
  try {
    const token = req.headers.authorization.split(' ')[1];
    const decoded = jwt.verify(token, process.env.JWT_SECRET);
    req.user = decoded;
    next();
  } catch (error) {
    res.status(401).json({ message: 'Ошибка аутентификации' });
  }
};

export default {
  namespaced: true,
  
  state: {
    token: localStorage.getItem('token') || null,
    user: null
  },

  getters: {
    isAuthenticated: state => !!state.token,
    user: state => state.user
  },

  mutations: {
    SET_TOKEN(state, token) {
      state.token = token
      localStorage.setItem('token', token)
    },
    SET_USER(state, user) {
      state.user = user
    },
    CLEAR_AUTH(state) {
      state.token = null
      state.user = null
      localStorage.removeItem('token')
    }
  },

  actions: {
    async register({ commit }, credentials) {
      try {
        const { token, user } = await api.auth.register(credentials)
        commit('SET_TOKEN', token)
        commit('SET_USER', user)
        return user
      } catch (error) {
        throw error
      }
    },

    async login({ commit }, credentials) {
      try {
        const { token, user } = await api.auth.login(credentials)
        commit('SET_TOKEN', token)
        commit('SET_USER', user)
        return user
      } catch (error) {
        throw error
      }
    },

    

    logout({ commit }) {
      commit('CLEAR_AUTH')
    }
  }
}