import { createRouter, createWebHistory } from 'vue-router'
import MainScreen from '../views/MainScreen.vue'  
import SignUp from '../views/SignUp.vue'
import SignIn from '../views/SignIn.vue'
import Home from '../views/Home.vue'  
import ProfilScreen from '../views/ProfilScreen.vue'
import SelectionScreen from '../views/SelectionScreen.vue'
import CollectionsScreen from '../views/CollectionsScreen.vue'
import ChatList from '../views/ChatList.vue'
import ChatScreen from '../views/ChatScreen.vue'
import CreateCollectionScreen from '../views/CreateCollectionScreen.vue'
import IconSelectionScreen from '../views/IconSelectionScreen.vue'
import ChatView from '../views/ChatView.vue'


const routes = [
  {
    path: '/',
    name: 'Home',
    component: Home
  },
  {
    path: '/mainscreen',
    name: 'MainScreen',
    component: MainScreen
  },

  {
    path: '/signup',
    name: 'SignUp',
    component: SignUp
  },
  {
    path: '/signin',
    name: 'SignIn',
    component: SignIn
  },
  {
    path: '/selection',
    name: 'Selection',
    component: SelectionScreen
  },
  {
    path: '/profil',
    name: 'Profil',
    component: ProfilScreen
  },
  {
    path: '/chats',
    name: 'ChatList',
    component: ChatList,
    meta: { requiresAuth: true }
  },
  {
    path: '/chat/:id',
    name: 'ChatScreen',
    component: ChatScreen,
    meta: { requiresAuth: true }
  },
  {
    path: '/',
    redirect: '/collections'
  },
  {
    path: '/collections',
    name: 'Collections',
    component: CollectionsScreen
  },
  {
    path: '/create-collection',
    name: 'CreateCollection',
    component: CreateCollectionScreen,
    props: true
  },
  {
    path: '/icon-selection',
    name: 'IconSelection',
    component: IconSelectionScreen,
    props: true
  },
  {
    path: '/collections/:id',
    name: 'CollectionDetails',
    component: CollectionsScreen,  
    props: true
  },
  {
    path: '/chat/:id',
    name: 'chat',
    component: ChatView
  }
]

const router = createRouter({
  history: createWebHistory(),
  routes
})

router.beforeEach((to, from, next) => {
  const publicPages = ['/signin', '/signup'];
  const authRequired = !publicPages.includes(to.path);
  const loggedIn = localStorage.getItem('token');

  if (authRequired && !loggedIn) {
    return next('/signin');
  }

  next();
});

const isAuthenticated = () => {
  const token = localStorage.getItem('token');
  if (!token) return false;
  

  const tokenData = JSON.parse(atob(token.split('.')[1])); 
  return tokenData.exp > Date.now() / 1000;
};

export default router;