export const API_CONFIG = {
  baseURL: import.meta.env.VITE_API_URL || 'https://cinema.kolei.ru/api',

  endpoints: {
    signin: '/auth/signin',
    signup: '/auth/signup',
    profile: '/user/profile',
    avatar: '/user/avatar'
  }
}

export const authAPI = {
  login: async (email, password) => {
    try {
      const users = JSON.parse(localStorage.getItem('users') || '[]')
      
      console.log('Попытка входа:', {
        введенныйEmail: email,
        введенныйПароль: password
      })
      console.log('Зарегистрированные пользователи:', users)

      const user = users.find(u => {
        const emailMatches = u.email.toLowerCase() === email.toLowerCase()
        const passwordMatches = u.password === password
        
        console.log('Проверка пользователя:', {
          сохраненныйEmail: u.email,
          emailСовпадает: emailMatches,
          парольСовпадает: passwordMatches
        })
        
        return emailMatches && passwordMatches
      })

      if (!user) {
        console.log('Пользователь не найден')
        throw new Error('Неверный email или пароль. Проверьте введенные данные или зарегистрируйтесь.')
      }
      const authData = {
        token: `auth-token-${Date.now()}`,
        user: {
          id: user.id,
          email: user.email,
          name: user.name,
          surname: user.surname
        }
      }

      console.log('Успешная авторизация:', authData)
   
      localStorage.setItem('token', authData.token)
      localStorage.setItem('user', JSON.stringify(authData.user))
      
      return authData
    } catch (error) {
      console.error('Ошибка при входе:', error)
      throw error
    }
  }
}

export const movieService = {
  async getNewMovies(pages = 3) {  
    try {
      const allMovies = [];
      
      for (let page = 1; page <= pages; page++) {
        const response = await fetch(`https://www.omdbapi.com/?apikey=ac4fc473&s=movie&type=movie&page=${page}`);
        if (!response.ok) {
          throw new Error(`HTTP error! status: ${response.status}`);
        }
        const data = await response.json();
        if (data.Search) {
          allMovies.push(...data.Search);
        }
      }

      return allMovies.map(movie => ({
        id: movie.imdbID,
        title: movie.Title,
        posterUrl: movie.Poster !== 'N/A' ? movie.Poster : 'placeholder.jpg'
      }));
    } catch (error) {
      console.error('Error fetching movies:', error);
      throw error;
    }
  }
}